#include "config.h"

#include <stdio.h>
#include <stdlib.h>

#ifdef USE_NLLIBC
#include <nllibc.h>
#endif

#include "const.h"
#include "image.h"
#include "charset.h"

#define CHARACTER_SIZE 64

#define TP 0x80 /* transparent */

#define B_   (1 << 0)
#define B__  (2 << 0)
#define B___ (3 << 0)
#define G_   (1 << 2)
#define G__  (2 << 2)
#define G___ (3 << 2)
#define R_   (1 << 4)
#define R__  (2 << 4)
#define R___ (3 << 4)

#define BK 0x00 /* black */

#define BL (          B___) /* blue */
#define GR (     G___     ) /* green */
#define CY (     G___|B___) /* cyan */
#define RD (R___          ) /* red */
#define MG (R___     |B___) /* magenta */
#define YL (R___|G___     ) /* yellow */
#define WH (R___|G___|B___) /* white */

#define B0 (        B_ )
#define B1 (        B__)
#define G0 (    G_     )
#define G1 (    G__    )
#define C0 (    G_ |B_ )
#define C1 (    G__|B__)
#define R0 (R_         )
#define R1 (R__        )
#define M0 (R_     |B_ )
#define M1 (R__    |B__)
#define Y0 (R_ |G_     )
#define Y1 (R__|G__    )
#define W0 (R_ |G_ |B_ )
#define W1 (R__|G__|B__)

#define C2 (     G_  |B__ )
#define C3 (     G_  |B___)
#define C4 (     G__ |B_  )
#define C5 (     G__ |B___)
#define C6 (     G___|B_  )
#define C7 (     G___|B__ )
#define M2 (R_       |B__ )
#define M3 (R_       |B___)
#define M4 (R__      |B_  )
#define M5 (R__      |B___)
#define M6 (R___     |B_  )
#define M7 (R___     |B__ )
#define Y2 (R_  |G__      )
#define Y3 (R_  |G___     )
#define Y4 (R__ |G_       )
#define Y5 (R__ |G___     )
#define Y6 (R___|G_       )
#define Y7 (R___|G__      )

#define Z0 (R_  |G_  |B__ )
#define Z1 (R_  |G_  |B___)
#define Z2 (R_  |G__ |B_  )
#define Z3 (R_  |G__ |B__ )
#define Z4 (R_  |G__ |B___)
#define Z5 (R_  |G___|B_  )
#define Z6 (R_  |G___|B__ )
#define Z7 (R_  |G___|B___)
#define Z8 (R__ |G_  |B_  )
#define Z9 (R__ |G_  |B__ )
#define ZA (R__ |G_  |B___)
#define ZB (R__ |G__ |B_  )
#define ZC (R__ |G__ |B___)
#define ZD (R__ |G___|B_  )
#define ZE (R__ |G___|B__ )
#define ZF (R__ |G___|B___)
#define ZG (R___|G_  |B_  )
#define ZH (R___|G_  |B__ )
#define ZI (R___|G_  |B___)
#define ZJ (R___|G__ |B_  )
#define ZK (R___|G__ |B__ )
#define ZL (R___|G__ |B___)
#define ZM (R___|G___|B_  )
#define ZN (R___|G___|B__ )

static unsigned char bitmap[] = {
  /* nijimasu-kun */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,

  /* nijimasu-kun (huu) */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,

  /* nijimasu-kun (x) */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,WH,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,

  /* nijimasu-kun (pun) */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,WH,RD,RD,WH,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,WH,WH,WH,RD,RD,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,

  /* nlkun */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,ZK,ZK,ZK,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,ZK,ZK,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,Y4,Y4,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,ZK,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,ZK,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,ZK,ZK,ZK,ZK,Y4,Y4,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,ZK,Y4,Y4,Y4,BK,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,ZK,ZK,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,WH,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,WH,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,WH,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,
  TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,ZK,BK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,WH,BK,ZK,BK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,
  TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,BK,ZK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,ZK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,
  TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,WH,BK,BK,WH,BK,BK,Y4,Y4,Y4,Y4,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,
  TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,WH,WH,BK,BK,BK,Y4,Y4,Y4,BK,ZK,ZK,BK,ZK,BK,Y4,Y4,Y4,Y4,Y4,Y4,BK,WH,BK,BK,WH,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,
  TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,BK,ZK,BK,ZK,ZK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,WH,WH,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,ZK,BK,BK,ZK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,BK,BK,Y4,Y4,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,Y4,Y4,BK,Y4,Y4,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,C7,C7,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,ZK,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,ZK,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,BK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,YL,YL,YL,ZK,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,YL,YL,YL,ZK,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,ZK,ZK,ZK,ZK,ZK,ZK,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* llchan */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,M7,M7,M7,M7,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,ZN,YL,YL,YL,YL,YL,YL,YL,YL,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,ZN,YL,YL,YL,YL,ZN,YL,YL,YL,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,ZN,ZN,ZN,ZN,YL,YL,YL,ZN,ZN,ZN,YL,YL,YL,ZN,ZN,ZN,ZN,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,ZN,YL,YL,YL,ZN,BK,BK,ZN,ZN,YL,YL,ZN,ZN,ZN,YL,YL,ZN,ZN,BK,BK,ZN,YL,M7,M7,M7,M7,M7,M7,M7,TP,TP,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,ZN,ZN,ZN,YL,BK,WH,WH,BK,ZN,ZN,YL,ZN,ZN,ZN,YL,YL,ZN,BK,WH,WH,BK,YL,YL,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,ZN,ZN,ZN,ZN,ZN,BK,WH,WH,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,WH,WH,BK,ZN,YL,YL,YL,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,ZN,ZN,YL,YL,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,ZN,ZN,ZN,ZN,ZN,BK,BK,WH,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,WH,BK,BK,ZN,ZN,YL,YL,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,ZN,ZN,ZN,ZN,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,ZN,ZN,ZN,YL,YL,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,ZN,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,ZN,YL,YL,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,ZN,ZN,ZN,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,YL,YL,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,YL,YL,YL,YL,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,YL,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,YL,YL,TP,YL,YL,YL,TP,YL,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,C7,C7,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,CY,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZK,TP,TP,TP,TP,TP,TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,C7,C7,C7,TP,TP,TP,TP,TP,TP,
  TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,CY,CY,CY,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZN,ZN,ZN,ZN,ZN,ZK,ZK,ZK,ZK,ZK,ZK,TP,C7,CY,CY,C7,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,C7,C7,C7,C7,TP,TP,TP,TP,TP,
  TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,CY,CY,CY,CY,TP,TP,M7,M7,M7,M7,ZK,ZK,ZK,ZK,ZN,ZN,ZK,ZK,ZK,M7,M7,M7,M7,C7,CY,CY,CY,CY,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,C7,C7,C7,C7,TP,TP,TP,TP,TP,
  TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,CY,CY,CY,CY,CY,M7,M7,M7,M7,M7,M7,ZK,ZK,ZK,ZK,ZK,ZK,ZK,M7,M7,M7,M7,M7,M7,CY,CY,CY,CY,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,C7,C7,C7,C7,TP,TP,TP,TP,TP,
  TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,ZN,CY,CY,CY,CY,CY,M7,M7,M7,M7,M7,M7,M7,ZK,RD,RD,RD,ZK,M7,M7,M7,M7,M7,M7,M7,CY,CY,CY,CY,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,C7,C7,C7,C7,C7,TP,TP,TP,TP,
  TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,CY,CY,CY,CY,CY,M7,M7,M7,M7,M7,M7,M7,RD,RD,RD,RD,RD,M7,M7,M7,M7,M7,M7,M7,CY,CY,CY,ZN,ZN,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,TP,TP,TP,TP,
  TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,CY,CY,CY,CY,CY,M7,M7,M7,M7,M7,M7,M7,RD,RD,RD,RD,RD,M7,M7,M7,M7,M7,M7,M7,CY,CY,ZN,ZN,ZN,ZN,ZN,C7,C7,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,TP,TP,TP,TP,
  TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,ZN,ZN,CY,CY,CY,C7,M7,M7,M7,M7,M7,M7,M7,RD,RD,RD,RD,RD,M7,M7,M7,M7,M7,M7,M7,CY,CY,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,
  TP,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,CY,C7,C7,ZK,M7,M7,M7,M7,M7,M7,RD,RD,RD,RD,RD,M7,M7,M7,M7,M7,M7,C7,C7,C7,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,
  TP,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,C7,ZK,ZK,ZK,ZK,ZK,M7,M7,M7,RD,RD,RD,M7,M7,M7,M7,M7,M7,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,
  TP,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,C7,C7,ZK,ZK,ZK,ZK,M7,M7,M7,M7,M7,ZK,M7,M7,M7,M7,M7,ZK,ZK,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,TP,
  TP,TP,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,C7,C7,ZK,ZK,ZK,M7,M7,M7,M7,M7,ZK,ZK,ZK,M7,M7,M7,M7,M7,ZK,C7,C7,C7,C7,C7,C7,C7,C7,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,C7,C7,C7,C7,ZN,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,C7,ZF,ZF,ZF,ZK,ZK,ZK,ZK,M7,M7,M7,ZK,ZK,ZK,ZK,ZK,M7,M7,M7,ZK,ZK,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,C7,C7,ZN,ZN,ZN,ZN,ZN,C7,C7,C7,C7,C7,ZF,ZF,ZF,ZF,ZF,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,ZF,ZF,ZN,ZN,ZN,ZN,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,C7,C7,C7,C7,C7,C7,C7,C7,C7,C7,ZF,ZF,ZF,ZF,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZL,ZL,ZL,WH,WH,WH,WH,ZL,WH,WH,WH,WH,ZL,WH,WH,WH,WH,ZL,WH,WH,WH,WH,ZL,WH,WH,WH,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,TP,TP,TP,TP,
  TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZL,ZL,ZL,ZL,ZL,WH,WH,ZL,ZL,ZL,WH,WH,ZL,ZL,ZL,WH,WH,ZL,ZL,ZL,WH,WH,ZL,ZL,ZL,WH,ZL,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,TP,TP,TP,
  TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,TP,TP,
  TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,TP,
  TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZL,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,
  TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZK,ZL,ZL,ZK,ZK,ZL,ZL,ZL,ZK,ZK,ZK,ZL,ZL,ZL,ZL,ZK,ZK,ZK,ZL,ZL,ZL,ZK,ZK,ZK,ZL,ZL,ZL,ZK,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,
  TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,
  TP,TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,
  TP,TP,TP,TP,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,ZF,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,ZN,RD,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,RD,ZK,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,RD,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,RD,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* boykun */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,RD,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,WH,RD,WH,RD,RD,RD,RD,RD,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,ZF,ZF,ZF,ZF,ZF,ZF,ZF,WH,WH,RD,RD,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,ZF,ZF,Z5,Z5,Z5,WH,WH,ZF,ZF,WH,WH,WH,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,ZF,ZF,ZF,Z5,WH,WH,WH,Z5,WH,WH,ZF,ZF,WH,WH,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,ZF,ZF,ZF,Z5,WH,WH,WH,Z5,WH,WH,ZF,ZF,WH,WH,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,ZF,ZF,ZF,Z5,Z5,Z5,Z5,Z5,WH,WH,ZF,ZF,ZF,ZF,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,ZF,ZF,ZF,ZF,Z5,Z5,Z5,Z5,Z5,WH,WH,ZF,ZF,ZF,ZF,ZF,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,ZF,Z5,Z5,Z5,Z5,Z5,WH,WH,ZF,ZF,WH,WH,WH,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,ZF,Z5,Z5,Z5,WH,WH,ZF,ZF,WH,WH,WH,WH,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,ZF,ZF,ZF,ZF,ZF,ZF,WH,WH,WH,WH,WH,RD,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,BK,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,WH,BK,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BL,BK,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,WH,WH,WH,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BL,BL,BL,BK,BK,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BL,BL,BL,BL,BL,BK,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BL,BL,BL,BL,BL,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BL,BL,BL,BL,BL,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,BL,BL,BL,WH,WH,WH,WH,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BK,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BK,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BK,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BK,BK,BK,BK,BK,BK,BK,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,B1,BK,B1,B1,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,B1,B1,B1,B1,B1,B1,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,B1,B1,B1,B1,B1,B1,B1,B1,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,B1,B1,B1,B1,B1,B1,B1,B1,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,B1,B1,B1,BL,BL,B1,B1,B1,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,TP,TP,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,BL,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* nssensei */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,BK,BK,ZN,ZN,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,ZN,ZN,BK,WH,WH,WH,WH,BK,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,ZN,ZN,BK,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,ZN,BK,WH,WH,WH,WH,BK,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,ZN,ZN,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,BK,BK,BK,ZN,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,ZN,ZN,BK,YL,YL,YL,YL,BK,ZN,ZN,ZN,ZN,BK,BK,ZN,BK,Z2,Z2,Z2,Z2,BK,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,ZN,ZN,BK,YL,YL,YL,YL,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,Z2,Z2,Z2,Z2,BK,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,ZN,ZN,ZN,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,ZN,ZN,ZN,ZN,ZN,BK,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,Z8,Z8,ZN,ZN,ZN,ZN,ZN,ZN,Z8,Z8,ZN,ZN,TP,TP,TP,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,Z8,Z8,Z8,ZN,ZN,ZN,ZN,Z8,Z8,Z8,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,Z8,Z8,Z8,Z8,Z8,Z8,Z8,Z8,Z8,Z8,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,Z8,Z8,Z8,Z8,Z8,Z8,Z8,Z8,Z8,Z8,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,Z8,Z8,BK,BK,BK,BK,BK,BK,Z8,Z8,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,YL,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,YL,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,YL,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Z2,Z2,BK,BK,Z2,Z2,BK,TP,TP,TP,TP,TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,Z2,Z2,Z2,Z2,Z2,Z2,BK,TP,TP,TP,TP,TP,TP,TP,ZN,RD,RD,BK,BK,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,Z2,Z2,BK,BK,Z2,Z2,BK,BK,TP,TP,TP,TP,TP,TP,BK,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,BK,RD,RD,BK,BK,RD,RD,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* paichan */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,TP,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M1,M1,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M7,M7,M7,M7,M1,M1,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M7,M7,M7,M1,M1,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M7,M7,M1,M1,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M1,M1,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M1,M1,YL,BK,BK,BK,YL,YL,YL,BK,BK,BK,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,YL,YL,ZK,ZK,ZK,ZK,YL,ZK,ZK,ZK,ZK,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,ZK,BK,BK,BK,ZK,ZK,ZK,BK,BK,BK,ZK,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,ZK,BK,WH,BK,ZK,ZK,ZK,BK,WH,BK,ZK,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,YL,YL,YL,ZK,BK,BK,BK,ZK,ZK,ZK,BK,BK,BK,ZK,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,B1,B1,R0,R0,R0,R0,TP,TP,TP,YL,YL,ZK,ZK,BK,M7,BK,ZK,ZK,ZK,BK,M7,BK,ZK,ZK,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,B1,B1,B1,R0,GR,R0,R0,TP,TP,YL,YL,ZK,ZK,BK,BK,BK,ZK,ZK,ZK,BK,BK,BK,ZK,ZK,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,B1,B1,R0,R0,GR,GR,R0,TP,TP,YL,YL,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,GR,GR,GR,R0,TP,TP,YL,YL,ZK,ZK,M7,M7,ZK,ZK,ZK,BK,ZK,ZK,M7,M7,ZK,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,ZK,R0,GR,R0,R0,TP,TP,YL,YL,ZK,ZK,M7,M7,ZK,ZK,ZK,R0,ZK,ZK,M7,M7,ZK,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,RD,RD,R0,ZK,R0,R0,R0,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,RD,RD,ZK,ZK,R0,R0,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,RD,R0,R0,R0,R0,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,ZK,ZK,ZK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,BK,BK,BK,TP,WH,WH,WH,WH,M7,M7,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,WH,ZK,ZK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,M7,M7,M7,M7,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,ZK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,M7,M7,M7,M7,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,G1,G1,WH,WH,WH,WH,BK,BK,WH,WH,M7,M7,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,G1,G1,G1,G1,WH,WH,WH,BK,BK,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,G1,G1,G1,G1,WH,WH,WH,BK,BK,BK,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,G1,G1,WH,WH,WH,WH,BK,WH,BK,WH,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,C7,C7,C7,C7,BK,BK,WH,WH,WH,R1,R1,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,BK,WH,YL,YL,YL,YL,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,C7,C7,C7,C7,WH,BK,WH,WH,R1,R1,R1,R1,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,BK,YL,YL,YL,YL,YL,YL,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,C7,C7,M6,M6,M6,BK,BK,WH,R1,R1,R1,R1,R1,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,YL,R0,R0,R0,YL,YL,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,C7,M6,M6,M6,M6,WH,BK,WH,WH,R1,R1,R1,R1,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,R0,R0,R0,R0,R0,R0,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,M6,M6,C1,C1,WH,BK,WH,WH,R1,R1,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,R0,R0,R0,R0,R0,R0,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,M6,M6,C1,C1,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,B1,WH,WH,WH,WH,WH,BK,WH,R0,R0,R0,R0,R0,R0,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,C1,C1,BK,BK,WH,WH,WH,WH,WH,WH,WH,B1,B1,B1,WH,WH,WH,WH,BK,WH,WH,R0,R0,R0,R0,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,WH,WH,C1,C1,BK,WH,WH,WH,WH,WH,WH,WH,WH,B1,B1,B1,WH,WH,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,C1,WH,BK,WH,WH,WH,WH,WH,WH,WH,B1,B1,B1,B1,WH,WH,BK,TP,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,B1,B1,B1,WH,WH,WH,BK,TP,TP,WH,WH,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,TP,TP,TP,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,BK,BK,BK,WH,WH,BK,BK,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,TP,BK,BK,BK,BK,TP,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,ZK,ZK,TP,TP,TP,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,ZK,ZK,TP,TP,TP,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,TP,TP,TP,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,TP,TP,TP,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,ZK,TP,TP,TP,ZK,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,CY,ZK,M7,M7,M7,TP,M7,M7,M7,ZK,CY,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,CY,CY,ZK,CY,CY,TP,CY,CY,ZK,CY,CY,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,CY,CY,CY,TP,TP,TP,CY,CY,CY,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* ntsensei */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,Z6,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,Z6,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,Z6,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,Z6,Z6,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,Z6,M7,M7,M7,M7,M7,M7,M7,M7,M7,ZC,ZC,ZC,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZK,ZK,ZK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,Z6,Z6,M7,M7,M7,M7,M7,M7,M7,ZK,ZK,ZC,M7,ZC,ZC,M7,M7,M7,TP,TP,TP,TP,TP,TP,BK,ZK,ZK,ZK,ZK,ZK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,Z6,M7,M7,M7,M7,M7,M7,M7,M7,ZK,ZK,ZC,M7,M7,ZC,M7,M7,M7,TP,TP,TP,TP,TP,TP,BK,ZK,ZK,ZK,ZK,ZK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,Z6,M7,M7,M7,M7,M7,M7,M7,M7,ZK,ZK,ZC,ZC,ZC,ZC,M7,M7,M7,M7,TP,TP,TP,TP,TP,BK,BK,ZK,ZK,ZK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,Z6,M7,M7,M7,M7,M7,M7,M7,M7,ZK,ZK,ZK,ZK,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,BK,ZK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,Z6,M7,M7,M7,M7,M7,M7,ZK,ZK,ZK,ZK,ZK,C6,C6,C6,C6,M7,M7,M7,TP,TP,TP,BK,ZK,ZK,ZK,ZK,ZK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,ZK,ZK,ZK,ZK,ZK,BK,BK,ZK,ZK,ZK,ZK,ZK,ZK,C6,C6,M7,M7,C6,C6,M7,M7,TP,TP,TP,M7,M7,ZK,ZK,ZK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,ZK,ZK,ZK,ZK,BK,WH,WH,BK,ZK,ZK,ZK,ZK,BK,BK,C6,C6,C6,C6,M7,M7,M7,TP,TP,M7,M7,M7,M7,ZK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,ZK,ZK,ZK,ZK,BK,BK,BK,BK,ZK,ZK,ZK,BK,BK,ZK,ZK,ZK,ZK,ZK,M7,M7,M7,TP,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,ZK,ZK,ZK,ZK,BK,M7,M7,BK,ZK,ZK,ZK,BK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,M7,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,ZK,ZK,ZK,ZK,ZK,BK,BK,ZK,ZK,BK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,M7,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,M7,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,BK,ZK,ZK,ZK,BK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,M7,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,BK,BK,BK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,WH,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,WH,WH,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,M7,M7,M7,M7,M7,M7,ZM,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,M7,M7,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,M7,M7,M7,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,M7,M7,M7,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,M7,M7,BK,BK,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,M7,M7,BK,TP,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,M7,M7,BK,TP,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,M7,M7,BK,TP,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,M7,M7,BK,BK,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,M7,M7,M7,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,M7,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,M7,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,M7,M7,M7,M7,M7,BK,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,WH,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,M7,M7,M7,M7,BK,WH,WH,WH,WH,BK,BK,M7,WH,WH,WH,WH,WH,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,M7,M7,BK,WH,WH,BK,BK,BK,TP,M7,M7,M7,WH,WH,WH,WH,M7,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,M7,M7,TP,TP,M7,M7,WH,WH,WH,WH,WH,WH,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,WH,WH,WH,M7,M7,M7,TP,TP,TP,M7,M7,WH,WH,WH,WH,WH,WH,WH,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,WH,WH,WH,M7,M7,M7,TP,TP,TP,M7,M7,M7,WH,WH,WH,WH,WH,WH,WH,WH,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,WH,WH,WH,M7,M7,M7,TP,TP,TP,M7,M7,M7,M7,WH,WH,WH,WH,WH,WH,WH,ZK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,M7,M7,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,WH,WH,WH,M7,M7,M7,TP,TP,TP,M7,M7,M7,M7,M7,WH,WH,WH,WH,WH,WH,ZK,BK,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,M7,M7,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,WH,WH,WH,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,M7,M7,WH,WH,WH,WH,WH,ZK,BK,BK,WH,WH,WH,WH,WH,WH,BK,WH,WH,M7,M7,M7,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,WH,WH,WH,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,M7,M7,M7,ZK,ZK,BK,BK,BK,BK,BK,BK,ZF,ZF,ZF,WH,M7,M7,M7,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,WH,WH,WH,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZF,WH,ZF,WH,M7,M7,M7,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,WH,WH,WH,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZF,ZF,ZF,ZF,ZF,M7,M7,M7,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,WH,WH,WH,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZF,WH,ZF,M7,M7,M7,M7,M7,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,WH,WH,WH,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZF,ZF,ZF,M7,M7,M7,M7,M7,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZF,M7,M7,M7,M7,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZF,ZF,ZF,ZF,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZF,ZF,WH,ZF,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZF,M7,ZF,ZF,ZF,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M7,M7,M7,ZF,M7,M7,M7,M7,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* kumachan */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,TP,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,
  TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,
  TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,
  TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,
  TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,
  TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,R1,R1,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,R1,R1,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,R1,R1,BK,R1,BK,R1,R1,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,R1,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,TP,TP,TP,TP,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,TP,TP,TP,TP,R1,R1,R1,R1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* brave */
  TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,
  TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BL,BL,BL,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BL,BL,BL,CY,WH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,Y1,Y1,Y1,Y1,Y1,Y1,Y1,YL,WH,WH,WH,WH,WH,WH,WH,WH,
  TP,TP,TP,TP,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,BL,BL,BL,BL,CY,CY,BL,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,YL,WH,WH,WH,WH,WH,WH,WH,WH,
  TP,TP,TP,TP,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,BL,BL,BL,BL,BL,BL,BL,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,YL,YL,WH,WH,WH,WH,WH,WH,WH,
  TP,TP,TP,TP,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,BL,BL,BL,BL,BL,BL,BL,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,YL,YL,YL,YL,YL,YL,YL,YL,
  TP,TP,TP,TP,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,BL,BL,BL,BL,BL,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BL,BL,BL,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,WH,WH,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,WH,WH,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,WH,WH,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,WH,WH,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,ZH,BK,ZH,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,ZH,BK,ZH,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,ZH,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,ZH,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,WH,WH,BK,WH,WH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,WH,WH,BK,WH,WH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,WH,WH,WH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,WH,WH,WH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,BK,R0,R0,BK,R0,BK,R0,R0,BK,R0,R0,R0,R0,R0,R0,R0,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,Y4,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,B1,B1,B1,B1,BL,BL,BL,BL,BL,B1,B1,B1,B1,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,B1,B1,B1,B1,B1,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,B1,B1,B1,B1,BL,BL,BL,BL,BL,BL,BL,BL,BL,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BL,BL,BL,B1,B1,B1,B1,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,BK,Y4,Y4,Y4,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,Y4,Y4,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,Y4,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,BL,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BL,BL,BL,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,ZH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,BL,BL,BL,BL,B1,B1,BL,BL,BL,BL,BL,BL,BL,BL,BL,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,ZH,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,BL,BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,BL,C6,ZH,ZH,ZH,ZH,ZH,ZH,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,BL,BL,BL,B1,B1,BL,BL,BL,BL,B1,BL,BL,BL,C6,C6,ZH,ZH,ZH,ZH,ZH,ZH,ZH,ZH,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,C6,C6,C6,C6,YL,YL,ZH,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,BL,BL,BL,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,C6,C6,C6,YL,YL,C6,C6,C6,C6,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,BL,BL,BL,B1,BL,BL,BL,BL,B1,B1,BL,BL,BL,BL,B1,C6,C6,C6,C6,C6,C6,C6,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,BL,B1,B1,BL,C6,C6,C6,C6,C6,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,BL,BL,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,R0,C6,C6,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,BL,BL,B1,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,BL,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,BL,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,B1,B1,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,BL,BL,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,B1,BL,TP,TP,BL,BL,TP,BL,BL,BL,TP,TP,TP,B1,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,B1,TP,TP,TP,TP,TP,TP,BL,BL,BL,TP,TP,TP,TP,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* brave (squat) */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,
  TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BL,BL,BL,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BL,BL,BL,CY,WH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,Y1,Y1,Y1,Y1,Y1,Y1,Y1,YL,WH,WH,WH,WH,WH,WH,WH,WH,
  TP,TP,TP,TP,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,BL,BL,BL,BL,CY,CY,BL,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,YL,WH,WH,WH,WH,WH,WH,WH,WH,
  TP,TP,TP,TP,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,BL,BL,BL,BL,BL,BL,BL,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,YL,YL,WH,WH,WH,WH,WH,WH,WH,
  TP,TP,TP,TP,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,BL,BL,BL,BL,BL,BL,BL,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,YL,YL,YL,YL,YL,YL,YL,YL,
  TP,TP,TP,TP,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,BL,BL,BL,BL,BL,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,Y1,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BL,BL,BL,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,WH,WH,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,WH,WH,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,WH,WH,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,WH,WH,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,ZH,BK,ZH,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,ZH,BK,ZH,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,ZH,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,ZH,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,WH,WH,BK,WH,WH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,WH,WH,BK,WH,WH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,WH,WH,WH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,WH,WH,WH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,R0,R0,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,BK,R0,R0,BK,R0,BK,R0,R0,BK,R0,R0,R0,R0,R0,R0,R0,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,Y4,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,B1,B1,B1,B1,BL,BL,BL,BL,BL,B1,B1,B1,B1,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,B1,B1,B1,B1,B1,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,B1,B1,B1,B1,BL,BL,BL,BL,BL,BL,BL,BL,BL,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BL,BL,BL,B1,B1,B1,B1,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,Y4,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,BK,Y4,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,Y4,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,Y4,Y4,Y4,Y4,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,BL,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BL,BL,BL,BK,BK,BK,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BK,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,BL,BL,BL,BL,B1,B1,BL,BL,BL,BL,BL,BL,R0,R0,R0,R0,R0,ZH,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,BL,BL,BL,R0,R0,R0,R0,ZH,ZH,ZH,R0,R0,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,BL,BL,BL,B1,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,BL,R0,R0,ZH,ZH,ZH,ZH,ZH,R0,R0,R0,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,B1,B1,BL,BL,B1,B1,BL,BL,BL,BL,B1,BL,BL,BL,C6,C6,ZH,ZH,ZH,ZH,ZH,ZH,ZH,ZH,BK,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,C6,C6,C6,C6,YL,YL,ZH,ZH,ZH,ZH,ZH,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  B1,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,C6,C6,C6,YL,YL,C6,C6,C6,C6,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,B1,B1,BL,BL,BL,BL,B1,C6,C6,C6,C6,C6,C6,C6,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,BL,B1,B1,BL,C6,C6,C6,C6,C6,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,TP,C6,C6,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,BL,B1,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,B1,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  BL,BL,BL,B1,BL,BL,BL,BL,BL,B1,BL,BL,BL,BL,BL,B1,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,BL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* warrior in armor */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,R0,R0,R0,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,R0,R0,R0,R0,R0,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,R0,R0,R0,R0,R0,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,R0,R0,R0,R0,R0,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,Y4,Y4,Y4,Y4,Y4,Y4,Y4,Y4,R0,R0,R0,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,R0,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,TP,TP,TP,TP,TP,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* mwuchan */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,Y6,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,Y6,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,YL,GR,GR,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,GR,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,BK,BK,BK,BK,BK,BK,ZM,BK,BK,BK,ZM,ZM,BK,ZM,ZM,ZM,BK,BK,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,BK,BK,BK,ZM,ZM,BK,ZM,ZM,BK,ZM,ZM,ZM,ZM,ZM,ZM,ZM,BK,BK,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,BK,BK,ZM,ZM,ZM,ZM,ZM,ZM,BK,ZM,ZM,ZM,ZM,ZM,ZM,ZM,BK,BK,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,RD,WH,BK,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,BK,WH,RD,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,RD,BK,ZM,ZM,ZM,ZM,WH,WH,ZM,ZM,WH,WH,ZM,ZM,ZM,ZM,BK,RD,RD,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,RD,BK,ZM,ZM,ZM,ZM,WH,WH,ZM,ZM,WH,WH,ZM,ZM,ZM,ZM,BK,RD,RD,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZM,ZM,ZM,ZM,RD,RD,ZM,ZM,RD,RD,ZM,ZM,ZM,ZM,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,BK,BK,BK,TP,TP,TP,TP,ZM,ZM,ZM,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZM,ZM,ZM,ZM,ZM,ZM,ZM,RD,RD,ZM,ZM,ZM,ZM,ZM,ZM,BK,BK,BK,TP,TP,TP,TP,ZM,ZM,ZM,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZM,ZM,ZM,ZM,ZM,ZM,ZM,M6,M6,ZM,ZM,ZM,ZM,ZM,ZM,ZM,BK,BK,TP,TP,TP,TP,ZM,ZM,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,TP,TP,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,TP,BK,BK,TP,TP,TP,TP,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,TP,TP,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,ZM,TP,BK,BK,TP,TP,TP,TP,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZM,ZM,ZM,ZM,TP,TP,TP,TP,TP,TP,BK,BK,TP,TP,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y6,Y6,RD,RD,RD,RD,Y6,Y6,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,Y6,Y6,Y6,Y6,Y6,Y6,YL,TP,TP,TP,TP,WH,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,BK,YL,YL,YL,YL,YL,YL,YL,YL,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,BK,BK,BK,GR,G1,G1,GR,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,BK,BK,BK,BK,GR,BK,BK,GR,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZM,WH,WH,WH,G1,G1,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZM,ZM,ZM,ZM,WH,G1,G1,G1,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZM,ZM,ZM,TP,TP,G1,G1,G1,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZM,TP,TP,TP,G1,G1,G1,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,G1,G1,G1,RD,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,G1,YL,Y6,RD,RD,RD,RD,RD,RD,RD,RD,RD,Y6,Y6,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,YL,Y6,Y6,Y6,Y6,Y6,Y6,Y6,Y6,Y6,Y6,Y6,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,GR,GR,YL,YL,YL,YL,Y6,Y6,Y6,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,YL,YL,YL,YL,Y6,Y6,Y6,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,GR,YL,YL,YL,YL,Y6,Y6,Y6,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,GR,YL,YL,YL,YL,Y6,Y6,Y6,Y6,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,GR,GR,YL,YL,YL,YL,Y6,Y6,Y6,Y6,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,GR,GR,YL,YL,YL,YL,Y6,Y6,Y6,Y6,RD,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,GR,GR,YL,YL,YL,YL,YL,Y6,Y6,Y6,Y6,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,GR,GR,GR,YL,YL,YL,YL,YL,Y6,Y6,Y6,Y6,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,GR,GR,GR,YL,YL,YL,YL,YL,YL,Y6,Y6,Y6,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,GR,GR,GR,GR,YL,YL,YL,YL,YL,Y6,Y6,Y6,RD,RD,RD,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZM,ZM,ZM,TP,TP,TP,ZM,ZM,ZM,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZM,ZM,ZM,TP,TP,TP,ZM,ZM,ZM,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZM,ZM,ZM,TP,TP,WH,ZM,WH,ZM,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,ZM,ZM,ZM,TP,TP,TP,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,TP,TP,TP,TP,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,WH,WH,WH,WH,TP,TP,TP,TP,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,WH,WH,TP,TP,TP,TP,TP,WH,WH,WH,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,WH,BK,TP,TP,TP,TP,BK,BK,BK,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,WH,BK,TP,TP,TP,TP,BK,BK,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,TP,TP,TP,BK,TP,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* treasure chest */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,R1,R1,R1,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R0,R1,R0,R1,R1,R1,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,R1,R1,R1,R1,R1,BK,BK,BK,BK,BK,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,R1,R1,R0,R1,R1,R1,R1,R1,BK,BK,BK,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,BK,BK,BK,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,BK,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R0,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,BK,BK,BK,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,BK,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,BK,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,R1,R1,R0,R1,R1,R1,R1,R1,R1,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,YL,YL,YL,YL,YL,YL,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,Y7,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,YL,YL,YL,BK,BK,YL,YL,YL,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,Y7,Y7,Y7,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,BK,BK,R1,R1,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,Y7,Y7,Y7,Y7,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,BK,R1,R1,R1,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,Y7,Y7,Y7,Y7,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,R1,R1,R1,R1,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,Y7,Y7,Y7,Y7,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,R1,R1,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,Y7,Y7,Y7,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,YL,YL,YL,R1,R1,YL,YL,YL,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,YL,YL,YL,YL,YL,YL,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R0,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R0,R1,R1,R1,R0,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R0,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R0,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R0,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R0,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R0,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,BK,BK,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R0,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* treasure chest (opened) */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R1,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R1,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R1,R1,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R1,R1,R1,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,Y7,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,YL,YL,YL,YL,YL,YL,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,Y7,Y7,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,YL,YL,YL,BK,BK,YL,YL,YL,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,Y7,Y7,Y7,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,BK,BK,R1,R1,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,Y7,Y7,Y7,Y7,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,BK,R1,R1,R1,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,Y7,Y7,Y7,Y7,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,R1,R1,R1,R1,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,Y7,Y7,Y7,Y7,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,R1,R1,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,Y7,Y7,Y7,R1,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,YL,YL,YL,R1,R1,YL,YL,YL,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,YL,YL,YL,YL,YL,YL,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R0,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R0,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R0,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R0,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R0,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R0,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,BK,BK,BK,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R1,R1,R1,R0,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R0,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,R1,BK,BK,BK,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* punin kun */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZN,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZN,ZN,ZN,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,ZN,BK,BK,BK,ZN,BK,BK,BK,BK,ZN,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,BK,BK,ZN,ZN,BK,BK,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZH,ZH,ZH,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZH,ZH,ZH,ZH,ZH,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,WH,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZH,ZH,ZH,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,M7,RD,RD,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,M7,M7,M7,RD,RD,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZH,ZH,ZH,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,M7,M7,M7,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZH,ZH,ZH,ZH,ZH,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZH,ZH,ZH,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,G0,G0,G0,G0,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,BK,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,TP,BK,BK,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,BK,BK,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZN,G0,G0,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,G0,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,G0,G0,G1,G0,G1,G0,G1,G0,G1,G0,G1,G0,G1,G0,G1,G0,G1,G0,G1,G0,BK,TP,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,G0,G1,G0,G1,G0,G1,G0,G1,G0,G1,G0,G1,G0,G1,G0,G1,G0,G1,BK,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,G0,ZN,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,R0,R0,W0,W0,W0,W0,R0,R0,R0,R0,R0,R0,R0,G0,G0,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,G1,R0,G1,R0,G1,R0,G1,W0,G1,BK,BK,BK,R0,G1,R0,G1,R0,G1,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,R0,R0,R0,R0,R0,R0,R0,W0,W0,W0,W0,R0,R0,R0,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,B0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,B0,B0,B0,B0,B0,B0,BK,BK,BK,BK,B0,B0,B0,B0,B0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,B0,B0,BK,TP,TP,TP,BK,B0,B0,B0,B0,B0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,BK,TP,TP,TP,TP,BK,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* punitaro */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,WH,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZH,ZH,ZH,ZN,BK,RD,RD,RD,BK,ZN,ZN,ZH,ZH,ZH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZH,ZH,ZH,ZN,BK,ZH,ZH,ZH,BK,ZN,ZN,ZH,ZH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,ZH,ZH,ZH,ZH,ZH,BK,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,ZN,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,GR,G1,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,G1,GR,GR,GR,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,GR,GR,G1,G1,BK,GR,GR,GR,GR,GR,G1,GR,GR,G1,G1,GR,GR,GR,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,GR,GR,BK,GR,GR,GR,GR,GR,GR,G1,G1,GR,GR,G1,GR,GR,GR,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,GR,GR,GR,GR,GR,GR,GR,G1,GR,GR,G1,GR,GR,GR,GR,GR,ZN,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,GR,GR,GR,BK,BK,BK,GR,W0,GR,GR,W0,GR,GR,GR,GR,GR,ZN,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,GR,GR,GR,BK,ZN,ZN,BK,GR,G1,GR,GR,G1,GR,GR,GR,GR,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,GR,GR,GR,GR,ZN,BK,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,GR,GR,GR,GR,GR,BK,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,GR,GR,GR,GR,GR,BK,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,W0,W0,W0,W0,W0,W0,W0,W0,C0,C0,BK,C0,C0,W0,W0,W0,W0,W0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,W0,W0,W0,W0,W0,W0,W0,C0,W0,C0,C0,C0,W0,C0,W0,W0,W0,W0,W0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,W0,W0,W0,W0,W0,W0,W0,W0,W0,C0,C0,W0,C0,C0,W0,W0,W0,W0,W0,W0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,C0,W0,C0,W0,W0,W0,W0,W0,W0,W0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,W0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,W0,W0,W0,W0,W0,W0,W0,BK,BK,BK,BK,BK,BK,W0,W0,W0,W0,W0,W0,W0,W0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,W0,W0,W0,W0,BK,TP,TP,TP,TP,TP,TP,BK,W0,W0,W0,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,W0,W0,W0,BK,TP,TP,TP,TP,TP,TP,BK,W0,W0,W0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,C0,C0,C0,B0,BK,TP,TP,TP,TP,TP,BK,C0,C0,C0,B0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,C0,C0,C0,C0,C0,B0,BK,TP,TP,TP,BK,C0,C0,C0,C0,C0,B0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,C0,C0,C0,C0,C0,C0,BK,TP,TP,TP,BK,C0,C0,C0,C0,C0,C0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* kawaii chan */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,ZB,WH,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,BK,WH,WH,WH,WH,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,BK,BK,WH,BK,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,BK,WH,WH,BK,WH,BK,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,BK,WH,WH,WH,WH,BK,BK,WH,WH,WH,WH,BK,WH,WH,WH,WH,BK,WH,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,BK,BK,BK,WH,WH,WH,WH,BK,WH,BK,BK,BK,BK,BK,WH,WH,BK,WH,BK,WH,WH,WH,WH,BK,WH,WH,WH,BK,BK,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,BK,BK,BK,BK,BK,WH,WH,WH,BK,WH,WH,WH,WH,BK,BK,BK,BK,WH,WH,BK,WH,WH,WH,WH,BK,BK,BK,BK,WH,BK,WH,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,BK,BK,BK,BK,BK,WH,WH,WH,BK,WH,WH,WH,WH,BK,BK,BK,WH,BK,WH,BK,WH,WH,WH,WH,BK,BK,WH,BK,WH,BK,WH,WH,WH,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,BK,BK,BK,BK,WH,WH,WH,WH,BK,WH,WH,WH,WH,BK,BK,WH,WH,WH,BK,BK,WH,WH,WH,WH,BK,WH,WH,WH,BK,BK,WH,WH,WH,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,BK,BK,WH,WH,WH,BK,BK,WH,WH,WH,WH,BK,WH,WH,WH,BK,BK,WH,WH,WH,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,WH,WH,WH,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,BK,WH,WH,WH,BK,BK,WH,WH,WH,WH,BK,BK,WH,WH,WH,BK,WH,WH,WH,BK,TP,TP,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,BK,BK,WH,WH,BK,BK,WH,WH,WH,WH,WH,BK,BK,WH,WH,BK,WH,WH,WH,BK,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,BK,BK,BK,WH,BK,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,WH,WH,WH,BK,TP,TP,TP,BK,BK,BK,RD,RD,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,WH,WH,WH,WH,BK,TP,TP,TP,BK,BK,RD,RD,BK,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,BK,BK,RD,RD,BK,BK,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,RD,RD,BK,BK,BK,BK,BK,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,RD,RD,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,RD,RD,BK,BK,BK,BK,BK,BK,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,ZH,ZH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,ZH,ZH,WH,WH,BK,TP,TP,TP,TP,BK,BK,BK,TP,BK,BK,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,ZH,ZH,ZH,ZH,WH,WH,WH,WH,RD,RD,WH,WH,RD,RD,WH,WH,WH,ZH,ZH,ZH,ZH,WH,BK,TP,TP,TP,BK,BK,BK,BK,TP,BK,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,BK,BK,BK,BK,BK,TP,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,ZH,ZH,ZH,ZH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,ZH,ZH,ZH,ZH,WH,BK,TP,TP,TP,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,BK,BK,BK,TP,TP,BK,BK,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,ZH,ZH,WH,WH,WH,WH,R0,R0,R0,R0,R0,R0,R0,R0,WH,WH,WH,ZH,ZH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,BK,TP,BK,BK,BK,BK,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,TP,TP,TP,BK,BK,BK,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,RD,RD,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,WH,WH,WH,WH,WH,RD,RD,WH,WH,WH,RD,RD,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,RD,RD,RD,RD,RD,RD,RD,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,RD,RD,RD,RD,RD,RD,RD,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,RD,RD,RD,RD,RD,RD,RD,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,CY,RD,RD,CY,CY,CY,RD,RD,CY,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,CY,CY,CY,CY,CY,CY,CY,CY,CY,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,CY,CY,CY,CY,CY,YL,CY,CY,CY,CY,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,CY,CY,CY,CY,CY,CY,CY,CY,CY,CY,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,CY,CY,CY,CY,CY,CY,CY,CY,CY,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,CY,CY,CY,CY,CY,YL,CY,CY,BK,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,CY,CY,CY,CY,CY,CY,CY,CY,BK,BK,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,CY,CY,CY,CY,CY,CY,CY,BK,TP,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,GR,GR,GR,GR,GR,GR,GR,GR,GR,TP,TP,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,BK,GR,GR,G1,GR,GR,GR,GR,GR,GR,GR,GR,TP,TP,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,TP,GR,GR,GR,G1,GR,G1,GR,GR,G1,GR,GR,GR,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,G1,GR,GR,G1,GR,GR,G1,G1,GR,GR,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,GR,GR,GR,GR,GR,G1,G1,GR,GR,GR,G1,G1,GR,GR,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,GR,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,BK,TP,BK,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,TP,TP,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,BK,TP,TP,TP,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,TP,TP,TP,TP,TP,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* marui kun */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,WH,BK,WH,BK,WH,BK,WH,BK,WH,BK,WH,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,BK,WH,BK,WH,BK,WH,WH,BK,WH,WH,BK,WH,BK,WH,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,WH,BK,WH,WH,BK,WH,BK,WH,WH,WH,BK,WH,WH,BK,WH,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,WH,BK,WH,WH,BK,WH,WH,BK,WH,WH,WH,WH,BK,WH,WH,BK,WH,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,WH,BK,WH,WH,BK,WH,WH,BK,WH,WH,WH,WH,WH,WH,BK,WH,WH,BK,WH,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,BK,BK,WH,BK,WH,WH,BK,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,BK,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,BK,WH,WH,BK,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,BK,BK,BK,WH,BK,BK,BK,BK,BK,BK,WH,WH,WH,BK,BK,WH,BK,WH,BK,WH,WH,WH,BK,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,BK,WH,WH,WH,BK,WH,WH,WH,BK,WH,BK,BK,WH,BK,BK,WH,WH,BK,WH,BK,WH,WH,BK,WH,BK,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,BK,BK,WH,BK,WH,BK,BK,WH,WH,WH,BK,BK,WH,BK,WH,BK,WH,BK,BK,BK,BK,BK,BK,BK,WH,WH,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,BK,BK,BK,WH,WH,BK,WH,BK,WH,WH,BK,WH,BK,BK,WH,BK,BK,WH,WH,BK,WH,BK,WH,WH,BK,BK,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,WH,BK,BK,BK,WH,BK,BK,BK,BK,BK,BK,WH,WH,WH,BK,BK,WH,WH,BK,WH,BK,BK,BK,BK,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,BK,BK,WH,BK,WH,WH,BK,BK,BK,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,BK,BK,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,Y0,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,WH,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,WH,WH,BK,WH,WH,WH,WH,BK,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,BK,WH,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,WH,WH,BK,BK,WH,WH,WH,WH,BK,WH,WH,WH,BK,WH,WH,WH,WH,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,BK,WH,WH,WH,BK,WH,WH,WH,BK,BK,WH,WH,WH,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,BK,WH,WH,WH,BK,WH,WH,BK,BK,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,WH,BK,WH,WH,BK,WH,WH,BK,BK,BK,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,BK,WH,WH,BK,WH,BK,BK,WH,BK,BK,WH,WH,WH,WH,BK,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,BK,WH,BK,WH,BK,WH,WH,BK,BK,WH,WH,WH,WH,WH,BK,WH,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,BK,WH,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,TP,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,BK,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,BK,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,WH,WH,WH,BK,BK,TP,TP,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,BK,BK,BK,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* onigiri kun */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,BK,BK,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,BK,BK,WH,BK,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,BK,WH,BK,WH,BK,BK,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,BK,WH,WH,BK,WH,BK,WH,BK,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,BK,WH,BK,WH,WH,BK,WH,WH,BK,WH,BK,WH,BK,WH,WH,BK,WH,WH,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,BK,WH,WH,BK,BK,WH,BK,WH,BK,WH,BK,WH,WH,BK,BK,WH,BK,WH,BK,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,M7,M7,M7,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,M7,M7,M7,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,M7,ZH,ZH,ZH,M7,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,M7,ZH,ZH,ZH,M7,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,M7,ZH,ZH,ZH,M7,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,M7,ZH,ZH,ZH,M7,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,M7,M7,M7,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,M7,M7,M7,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,WH,WH,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,WH,WH,BK,BK,BK,BK,WH,WH,BK,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,BK,WH,WH,BK,BK,BK,BK,WH,WH,BK,BK,WH,WH,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,WH,BK,BK,BK,WH,WH,BK,BK,WH,WH,BK,BK,BK,WH,WH,BK,R1,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,BK,WH,WH,WH,WH,BK,WH,WH,WH,WH,WH,WH,BK,WH,WH,WH,WH,BK,WH,WH,R1,WH,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,M0,WH,WH,BK,BK,WH,BK,WH,BK,BK,WH,WH,WH,WH,BK,BK,WH,BK,WH,BK,R1,WH,WH,WH,WH,R1,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,M0,WH,M0,BK,WH,BK,WH,WH,BK,BK,WH,WH,WH,WH,BK,BK,WH,WH,BK,WH,WH,WH,R1,WH,WH,WH,WH,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,WH,M0,BK,BK,WH,WH,WH,BK,BK,WH,WH,WH,WH,BK,BK,WH,WH,WH,BK,R1,WH,WH,WH,R1,WH,WH,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,BK,WH,WH,WH,BK,WH,BK,BK,BK,W1,W1,ZK,BK,ZK,W1,W1,BK,BK,BK,BK,WH,BK,WH,WH,WH,WH,WH,R1,BK,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,BK,WH,M0,WH,BK,ZK,ZK,WH,WH,W1,W1,ZK,W1,ZK,W1,W1,WH,WH,WH,WH,WH,G0,BK,WH,R1,WH,WH,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,BK,WH,M0,WH,BK,ZK,ZK,WH,WH,W1,W1,ZK,W1,ZK,W1,W1,G0,WH,WH,WH,WH,G0,BK,BK,WH,WH,R1,BK,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,BK,BK,WH,WH,BK,WH,WH,WH,WH,W1,W1,ZJ,ZJ,ZJ,W1,W1,G0,WH,WH,G0,WH,WH,BK,BK,BK,BK,BK,TP,BK,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,BK,WH,BK,BK,TP,BK,BK,BK,BK,WH,WH,WH,WH,WH,ZJ,ZJ,BK,ZJ,ZJ,WH,WH,WH,WH,G0,WH,WH,BK,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,TP,BK,TP,TP,TP,TP,TP,TP,BK,WH,ZK,ZK,ZK,WH,WH,WH,BK,WH,RD,WH,WH,G0,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,BK,BK,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,ZK,ZK,WH,WH,WH,BK,WH,WH,WH,WH,G0,WH,WH,G0,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,WH,WH,WH,WH,ZK,ZK,BK,WH,RD,G0,WH,WH,WH,WH,G0,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,WH,ZK,ZK,WH,WH,ZK,ZK,BK,WH,WH,G0,WH,WH,WH,WH,WH,WH,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,R0,R0,R0,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,R0,R0,R0,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,R0,R0,R0,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,BK,BK,R0,R0,R0,R0,R0,R0,R0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,R0,R0,R0,R0,R0,R0,R0,R0,R0,R0,BK,TP,BK,R0,R0,R0,R0,R0,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,BK,BK,BK,BK,BK,G0,G0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,Y7,YL,G0,G0,G0,G0,G0,BK,TP,TP,TP,TP,TP,YL,Y7,YL,G0,G0,G0,G0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,Y7,YL,G0,G0,G0,G0,G0,G0,BK,TP,TP,TP,TP,YL,Y7,YL,G0,G0,G0,G0,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,Y7,BK,Y7,G0,G0,G0,G0,BK,BK,BK,TP,TP,TP,TP,Y7,BK,Y7,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,BK,BK,BK,BK,BK,BK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
};

struct charset charset_character = {
  CHARACTER_SIZE, CHARACTER_SIZE,
  sizeof(bitmap) / (sizeof(*bitmap) * CHARACTER_SIZE * CHARACTER_SIZE),
  { NULL, bitmap },
  IMAGE_TYPE_ROUGHCOLOR, NLL_G_STATIC
};
